

LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;
USE IEEE.NUMERIC_STD.ALL; 

LIBRARY STD; 
USE STD.TEXTIO.ALL;


ENTITY MemCtrlsdram_tb000 IS
END MemCtrlsdram_tb000;

ARCHITECTURE a_Tb000 OF MemCtrlsdram_tb000 IS

   COMPONENT ExternalBoard IS
   PORT(
      ul_Clk_i               : IN  STD_ULOGIC;  -- Clock
      ul_Rst_i               : IN  STD_ULOGIC;  -- Reset (1 = reset)
   
      ul_Start_o             : IN STD_ULOGIC;                       
      ulv32_Data_o           : OUT STD_ULOGIC_VECTOR(31 DOWNTO 0);  
      ulv32_Addr_i           : IN  STD_ULOGIC_VECTOR(31 DOWNTO 0);  
      ulv32_Test_i           : IN  STD_ULOGIC_VECTOR(31 DOWNTO 0);  
      ulv32_Test1_i          : IN  STD_ULOGIC_VECTOR(31 DOWNTO 0)  
   );
   END COMPONENT ExternalBoard;
   
   SIGNAL ul_Clock_s      : STD_ULOGIC := '0';
   SIGNAL ul_Reset_s      : STD_ULOGIC := '0';
   SIGNAL ul_start_s      : STD_ULOGIC := '0';
   SIGNAL ulv32_Data_s    : STD_ULOGIC_VECTOR(31 DOWNTO 0) := (OTHERS => '0');
   SIGNAL ulv32_Addr_s    : STD_ULOGIC_VECTOR(31 DOWNTO 0) := (OTHERS => '0');
   SIGNAL ulv32_Test_s    : STD_ULOGIC_VECTOR(31 DOWNTO 0) := (OTHERS => '0');
   SIGNAL ulv32_Test1_s   : STD_ULOGIC_VECTOR(31 DOWNTO 0) := (OTHERS => '0');

BEGIN

   -- 150MHz clock
   p_ClockProcess : PROCESS
   BEGIN
      WAIT FOR 3.333 ns;
      ul_Clock_s <= NOT(ul_Clock_s);
   END PROCESS p_ClockProcess;
   
   -- Reset signal

   p_ResetProcess : PROCESS
   BEGIN
      WAIT FOR 100 ns;
      ul_Reset_s <= '0';
      WAIT;
   END PROCESS p_ResetProcess;
   
   -- The UUT
   
   ExternalBoard_inst : COMPONENT ExternalBoard
   PORT MAP(
       ul_Clk_i               => ul_Clock_s,
       ul_Rst_i               => ul_Reset_s,
     
       ul_Start_o             => ul_start_s,
       ulv32_Data_o           => ulv32_Data_s, 
       ulv32_Addr_i           => ulv32_Addr_s, 
       ulv32_Test_i           => ulv32_Test_s, 
       ulv32_Test1_i          => ulv32_Test1_s
   ); 
   
   -- Test Bench Process.
   
   p_TestBenchProc : PROCESS
   
      VARIABLE FileStatus_v                  : FILE_OPEN_STATUS := OPEN_OK;
      FILE fl_myFile_f                       : TEXT;  
   
   BEGIN
      
      -- Open console output
      
      FILE_OPEN(FileStatus_v, fl_myFile_f, "STD_OUTPUT", WRITE_MODE);
   
      -- Test bench stimuli
   
      ASSERT FALSE REPORT ">>> Test Bench Start" SEVERITY NOTE; 
      
      -- Wait until SDRAM reset process completes
      
      WAIT FOR 110 us;
      WAIT UNTIL RISING_EDGE(ul_Clock_s);
   	
      ul_start_s <= '1';      


      -- Close Console output
      
      FILE_CLOSE(fl_myFile_f);
      
      WAIT;   
      
   END PROCESS p_TestBenchProc;

END;   